@@ -12,7 +12,7 @@ import os
 import subprocess
 import json
 import xmltodict
- 
+from datetime import datetime 
  
 docker = Config.docker_client
 
@@ -204,3 +204,14 @@ def convertXmlToJson(file_name,path,output_file):
     except Exception as e:
         return 0
 
+def logError(msg,error):
+    f = open("bomancli.errors.log", "a")
+    msg = msg+'\n'
+    # writing in the file
+    now = datetime.now()
+    f.write('\n===========================================================\n')
+    f.write(str(now))
+    f.write(str(msg))
+    f.write(str(error)) 
+     # closing the file
+    f.close()
\ No newline at end of file
